@@ -27,7 +27,6 @@ use state::{
     ClipRule,
     CompOp,
     ComputedValues,
-    EnableBackground,
     FillRule,
     ShapeRendering,
     StrokeDasharray,
@@ -117,8 +116,6 @@ pub struct DrawingCtx<'a> {
     cr: cairo::Context,
     initial_cr: cairo::Context,
 
-    surfaces_stack: Vec<cairo::ImageSurface>,
-
     view_box_stack: Rc<RefCell<Vec<ViewBox>>>,
 
     bbox: BoundingBox,
@@ -176,7 +173,6 @@ impl<'a> DrawingCtx<'a> {
             cr_stack: Vec::new(),
             cr: cr.clone(),
             initial_cr: cr.clone(),
-            surfaces_stack: Vec::new(),
             view_box_stack: Rc::new(RefCell::new(view_box_stack)),
             bbox: BoundingBox::new(&affine),
             bbox_stack: Vec::new(),
@@ -392,21 +388,34 @@ impl<'a> DrawingCtx<'a> {
                 && filter.is_none()
                 && mask.is_none()
                 && (clip_units == None || clip_units == Some(CoordUnits::UserSpaceOnUse))
-                && comp_op == CompOp::SrcOver
-                && enable_background == EnableBackground::Accumulate);
+                && comp_op == CompOp::SrcOver);
 
             if needs_temporary_surface {
-                let surface = cairo::ImageSurface::create(
-                    cairo::Format::ARgb32,
-                    self.rect.width as i32,
-                    self.rect.height as i32,
-                )?;
+                let cr = if filter.is_some() {
+                    cairo::Context::new(&cairo::ImageSurface::create(
+                        cairo::Format::ARgb32,
+                        self.rect.width as i32,
+                        self.rect.height as i32,
+                    )?)
+                } else {
+                    // FIXME: cairo-rs should return a Result from create_similar()!
+                    // Since it doesn't, we need to check its status by hand...
 
-                if filter.is_some() {
-                    self.surfaces_stack.push(surface.clone());
-                }
+                    let surface = cairo::Surface::create_similar(
+                        &self.cr.get_target(),
+                        cairo::Content::ColorAlpha,
+                        self.rect.width as i32,
+                        self.rect.height as i32,
+                    );
+
+                    let status = surface.status();
+                    if status != cairo::Status::Success {
+                        return Err(RenderingError::Cairo(status));
+                    }
+
+                    cairo::Context::new(&surface)
+                };
 
-                let cr = cairo::Context::new(&surface);
                 cr.set_matrix(affine);
 
                 self.cr_stack.push(self.cr.clone());
@@ -419,12 +428,13 @@ impl<'a> DrawingCtx<'a> {
             let mut res = draw_fn(self);
 
             if needs_temporary_surface {
-                let child_surface = cairo::ImageSurface::from(self.cr.get_target()).unwrap();
-
-                let filter_result_surface = if let Some(filter_uri) = filter {
-                    self.run_filter(filter_uri, node, values, &child_surface)?
+                let source_surface = if let Some(filter_uri) = filter {
+                    let child_surface = cairo::ImageSurface::from(self.cr.get_target()).unwrap();
+                    let img_surface = self.run_filter(filter_uri, node, values, &child_surface)?;
+                    // turn into a Surface
+                    img_surface.as_ref().clone()
                 } else {
-                    child_surface
+                    self.cr.get_target()
                 };
 
                 self.cr = self.cr_stack.pop().unwrap();
@@ -432,7 +442,7 @@ impl<'a> DrawingCtx<'a> {
                 let (xofs, yofs) = self.get_offset();
 
                 original_cr.identity_matrix();
-                original_cr.set_source_surface(&filter_result_surface, xofs, yofs);
+                original_cr.set_source_surface(&source_surface, xofs, yofs);
 
                 if clip_units == Some(CoordUnits::ObjectBoundingBox) {
                     let clip_node = acquired_clip.as_ref().unwrap().get();
@@ -490,15 +500,13 @@ impl<'a> DrawingCtx<'a> {
         values: &ComputedValues,
         child_surface: &cairo::ImageSurface,
     ) -> Result<cairo::ImageSurface, RenderingError> {
-        let output = self.surfaces_stack.pop().unwrap();
-
         match self.get_acquired_node_of_type(Some(filter_uri), NodeType::Filter) {
             Some(acquired) => {
                 let filter_node = acquired.get();
 
                 if !filter_node.is_in_error() {
                     // FIXME: deal with out of memory here
-                    filters::render(&filter_node, values, &output, self)
+                    filters::render(&filter_node, values, child_surface, self)
                 } else {
                     Ok(child_surface.clone())
                 }
