@@ -31,6 +31,104 @@ handle_has_gtype (void)
     g_object_unref (handle);
 }
 
+static gboolean
+flags_value_matches (GFlagsValue *v,
+                     guint value,
+                     const char *value_name,
+                     const char *value_nick)
+{
+    return (v->value == value
+            && strcmp (v->value_name, value_name) == 0
+            && strcmp (v->value_nick, value_nick) == 0);
+}
+
+static void
+flags_registration (void)
+{
+    GType ty;
+    GTypeQuery q;
+    GTypeClass *type_class;
+    GFlagsClass *flags_class;
+
+    ty = RSVG_TYPE_HANDLE_FLAGS;
+
+    g_assert (ty != G_TYPE_INVALID);
+
+    g_type_query (RSVG_TYPE_HANDLE_FLAGS, &q);
+    g_assert (q.type == ty);
+    g_assert (G_TYPE_IS_FLAGS (q.type));
+    g_assert_cmpstr (q.type_name, ==, "RsvgHandleFlags");
+
+    type_class = g_type_class_ref (ty);
+    g_assert (G_IS_FLAGS_CLASS (type_class));
+    g_assert (G_FLAGS_CLASS_TYPE (type_class) == ty);
+
+    flags_class = G_FLAGS_CLASS (type_class);
+    g_assert (flags_class->n_values == 3);
+
+    g_assert (flags_value_matches(&flags_class->values[0],
+                                  RSVG_HANDLE_FLAGS_NONE,
+                                  "RSVG_HANDLE_FLAGS_NONE",
+                                  "flags-none"));
+
+    g_assert (flags_value_matches(&flags_class->values[1],
+                                  RSVG_HANDLE_FLAG_UNLIMITED,
+                                  "RSVG_HANDLE_FLAG_UNLIMITED",
+                                  "flag-unlimited"));
+
+    g_assert (flags_value_matches(&flags_class->values[2],
+                                  RSVG_HANDLE_FLAG_KEEP_IMAGE_DATA,
+                                  "RSVG_HANDLE_FLAG_KEEP_IMAGE_DATA",
+                                  "flag-keep-image-data"));
+
+    g_type_class_unref (type_class);
+}
+
+static gboolean
+enum_value_matches (GEnumValue *v,
+                    gint value,
+                    const char *value_name,
+                    const char *value_nick)
+{
+    return (v->value == value
+            && strcmp (v->value_name, value_name) == 0
+            && strcmp (v->value_nick, value_nick) == 0);
+}
+
+static void
+error_registration (void)
+{
+    GType ty;
+    GTypeQuery q;
+    GTypeClass *type_class;
+    GEnumClass *enum_class;
+
+    g_assert_cmpint (RSVG_ERROR, !=, 0);
+
+    ty = RSVG_TYPE_ERROR;
+
+    g_assert (ty != G_TYPE_INVALID);
+
+    g_type_query (ty, &q);
+    g_assert (q.type == ty);
+    g_assert (G_TYPE_IS_ENUM (q.type));
+    g_assert_cmpstr (q.type_name, ==, "RsvgError");
+
+    type_class = g_type_class_ref (ty);
+    g_assert (G_IS_ENUM_CLASS (type_class));
+    g_assert (G_ENUM_CLASS_TYPE (type_class) == ty);
+
+    enum_class = G_ENUM_CLASS (type_class);
+    g_assert (enum_class->n_values == 1);
+
+    g_assert (enum_value_matches (&enum_class->values[0],
+                                  RSVG_ERROR_FAILED,
+                                  "RSVG_ERROR_FAILED",
+                                  "failed"));
+
+    g_type_class_unref (type_class);
+}
+
 static char *
 get_test_filename (const char *basename) {
     return g_build_filename (test_utils_get_test_data_path (),
@@ -208,26 +306,6 @@ set_dpi (void)
     g_assert_cmpint (dim_100_dpi.height * 3, ==, dim_200_300_dpi.height);
 }
 
-static void
-error_quark (void)
-{
-    g_assert_cmpint (rsvg_error_quark(), !=, 0);
-}
-
-static void
-auto_generated (void)
-{
-    GTypeQuery q;
-
-    g_type_query (RSVG_TYPE_ERROR, &q);
-    g_assert (G_TYPE_IS_ENUM (q.type));
-    g_assert_cmpstr (q.type_name, ==, "RsvgError");
-
-    g_type_query (RSVG_TYPE_HANDLE_FLAGS, &q);
-    g_assert (G_TYPE_IS_FLAGS (q.type));
-    g_assert_cmpstr (q.type_name, ==, "RsvgHandleFlags");
-}
-
 static void
 handle_write_close_free (void)
 {
@@ -622,10 +700,10 @@ main (int argc, char **argv)
     }
 
     g_test_add_func ("/api/handle_has_gtype", handle_has_gtype);
+    g_test_add_func ("/api/flags_registration", flags_registration);
+    g_test_add_func ("/api/error_registration", error_registration);
     g_test_add_func ("/api/noops", noops);
     g_test_add_func ("/api/set_dpi", set_dpi);
-    g_test_add_func ("/api/error_quark", error_quark);
-    g_test_add_func ("/api/auto_generated", auto_generated);
     g_test_add_func ("/api/handle_write_close_free", handle_write_close_free);
     g_test_add_func ("/api/handle_new_from_file", handle_new_from_file);
     g_test_add_func ("/api/handle_new_from_data", handle_new_from_data);
